@@ -1,4 +1,4 @@
-/*	$NetBSD: tty.h,v 1.22 2018/01/01 22:32:46 christos Exp $	*/
+/*	$NetBSD: tty.h,v 1.24 2021/07/31 20:51:32 andvar Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -432,7 +432,7 @@
 #define	C_SH(A)		((unsigned int)(1 << (A)))
 
 /*
- * Terminal dependend data structures
+ * Terminal dependent data structures
  */
 #define	EX_IO	0	/* while we are executing	*/
 #define	ED_IO	1	/* while we are editing		*/
@@ -464,6 +464,7 @@ libedit_private int	tty_cookedmode(EditLine *);
 libedit_private int	tty_quotemode(EditLine *);
 libedit_private int	tty_noquotemode(EditLine *);
 libedit_private void	tty_bind_char(EditLine *, int);
+libedit_private int	tty_get_signal_character(EditLine *, int);
 
 typedef struct {
     ttyperm_t t_t;
